==> scorchful-0.15.5%2B1.21.4-sources.jar: com/github/thedeathlycow/scorchful/temperature/heatvision/EntityHeatVision.java <==
package com.github.thedeathlycow.scorchful.temperature.heatvision;

import com.github.thedeathlycow.scorchful.components.ScorchfulComponents;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1959;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_3730;
import net.minecraft.class_6862;

public class EntityHeatVision<E extends class_1297> extends HeatVision {


    private final class_1299<E> entityType;

    public EntityHeatVision(class_6862<class_1959> allowedBiomes, int weight, class_1299<E> entityType) {
        super(allowedBiomes, weight);
        this.entityType = entityType;
    }

    @Override
    public boolean spawn(class_1657 player, class_3218 world, class_2338 pos) {
        E entity = entityType.method_5883(world, class_3730.field_16459);

        if (entity != null) {
            entity.method_5725(pos, 0f, 0f);
            this.initializeEntity(entity);
            ScorchfulComponents.ENTITY_DESERT_VISION.get(entity).applyDesertVision(this, player);
            boolean spawned = world.method_8649(entity);
            if (spawned) {
                ScorchfulComponents.ENTITY_DESERT_VISION.sync(entity);
            }
            return spawned;
        }

        return false;
    }

    protected void initializeEntity(E entity) {
        entity.method_5684(true);
        entity.method_5875(true);
        entity.method_5803(true);
        if (entity instanceof class_1308 mob) {
            mob.method_5977(true);
        }
    }

}

==> scorchful-0.15.8%2B1.21.1-sources.jar: com/github/thedeathlycow/scorchful/temperature/heatvision/EntityHeatVision.java <==
package com.github.thedeathlycow.scorchful.temperature.heatvision;

import com.github.thedeathlycow.scorchful.components.ScorchfulComponents;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1959;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_6862;

public class EntityHeatVision<E extends class_1297> extends HeatVision {


    private final class_1299<E> entityType;

    public EntityHeatVision(class_6862<class_1959> allowedBiomes, int weight, class_1299<E> entityType) {
        super(allowedBiomes, weight);
        this.entityType = entityType;
    }

    @Override
    public boolean spawn(class_1657 player, class_3218 world, class_2338 pos) {
        E entity = entityType.method_5883(world);

        if (entity != null) {
            entity.method_5725(pos, 0f, 0f);
            this.initializeEntity(entity);
            ScorchfulComponents.ENTITY_DESERT_VISION.get(entity).applyDesertVision(this, player);
            boolean spawned = world.method_8649(entity);
            if (spawned) {
                ScorchfulComponents.ENTITY_DESERT_VISION.sync(entity);
            }
            return spawned;
        }

        return false;
    }

    protected void initializeEntity(E entity) {
        entity.method_5684(true);
        entity.method_5875(true);
        entity.method_5803(true);
        if (entity instanceof class_1308 mob) {
            mob.method_5977(true);
        }
    }

}
